#*************************************************************
# Progamm:			isa_atmosphaere_absorption
# Sinn des Programms: 		Berechnung der Summe zweier Float-Zahlen
# Sinn der Einheit  :		Hauptprogramm	
# Name dieser Datei:		isa_atmosphaere_absorption.py
# Versionsnummer:		1
# Wird aufgerufen von:		-
# Ruft auf:			zeit.py
# Nummer im Programmpaket:	1
# von:				2			
# Autor: 			Armin Ulrich
# Erster Lauf: 			22.04.2019
# Letzte Änderung: 		05.01.2020
#*************************************************************

#*************************************************************
# Importieren der Klassen zur Zeitdokumentation
#*************************************************************
import time
import datetime


#*************************************************************
# Importieren der Klassen
#*************************************************************

from steuer import Steuer
from gitter import Gitter
from ISA_lese import ISA_lese
from rechner import Rechner
from ausgabe import Ausgabe

steuer = Steuer()
gitter = Gitter()
isa_lese = ISA_lese()
rechner = Rechner()
ausgabe = Ausgabe()

#*************************************************************
# Berechnung der Startzeit des Programmes mit:
# a) datetime
# b) time
# und Konvertieren der Startzeit zu einem String "datum_zeit"
#*************************************************************
dt_start = datetime.datetime.now()
lt_start = time.localtime()
jahr, monat, tag, stunde, minute, sekunde  = lt_start[0:6]
datum_zeit = "Datum: " +str(tag)+"."+str(monat)+"."+str(jahr)+"\n"+"Zeit: "+str(stunde)+":"+str(minute)+":"+str(sekunde)

#*************************************************************
# Öffnen der Logdatei
#*************************************************************
fobj_log = open("isa_atmosphaere_absorption.log","w")

#*************************************************************
# Schreiben von Datum und Zeit des Programmstarts 
# in die Logdatei 
#*************************************************************
fobj_log.write("Anfang: "+ "\n" + datum_zeit)
fobj_log.write("\n")

print("isa_atmosphaere_absorption")

#*************************************************************
# Prüfung, ob Steuerdatei erfolgreich geöffnet wurde
#*************************************************************
if(steuer.steuer_input()):
  fobj_log.write( "Datei existiert\n")
else:
  fobj_log.write( "Datei existiert nicht\n")

#*************************************************************
# Einlesen des Gitters
#*************************************************************
gitter.gitter_input(steuer.gitter_datei)


if(isa_lese.isa_input()):
  fobj_log.write( "Datei existiert\n")
else:
  fobj_log.write( "Datei existiert nicht\n")

#rechner.interpolation()
rechner.kappa_rechner(steuer.Intens_init,steuer.kappa_anfang,steuer.kappa_ende,steuer.kappa_schrittweite,gitter.i_max,gitter.x,gitter.delta_x,isa_lese.i_max,isa_lese.höhe,isa_lese.rho_rel)
ausgabe.schirm_ausgabe(rechner.k_max, rechner.kappa_init_feld, rechner.Intens_absorbiert)
ausgabe.datei_ausgabe(steuer.ausgabe_datei, rechner.k_max, rechner.kappa_init_feld,  rechner.Intens_absorbiert)
ausgabe.graphik_ausgabe(rechner.k_max,steuer.kappa_anfang,steuer.kappa_ende, rechner.kappa_init_feld, rechner.Intens_absorbiert)

#*************************************************************
# Berechnung der Endzeit des Programmes mit:
# a) datetime
# b) time
# und Konvertieren der Endzeit zu einem String "datum_zeit"
#*************************************************************
lt_end = time.localtime()
jahr, monat, tag, stunde, minute, sekunde  = lt_end[0:6]
datum_zeit = "Datum: "+str(tag)+"."+str(monat)+"."+str(jahr)+"\n"+"Zeit: "+str(stunde)+":"+str(minute)+":"+str(sekunde)
dt_end = datetime.datetime.now()

#*************************************************************
# Berechnung der Rechendauer mit dem Zeitdifferenzoperator 
# des Moduls datetime
#*************************************************************
dauer = dt_end - dt_start

#*************************************************************
# Schreiben von Datum und Zeit des Programmendes und der 
# Rechendauer in die Logdatei 
#*************************************************************
fobj_log.write("Ende: "+ "\n" +datum_zeit + "\n")
fobj_log.write("Rechendauer: "+ "\n" + str(dauer))

#*************************************************************
# Schließen der Logdatei
#*************************************************************
fobj_log.close()

#*************************************************************
#Programmende
#*************************************************************

